@@ -3,14 +3,18 @@
   
     ## add id column if missing
     if(add.id){
-        n <- dbGetQuery(con, paste("SELECT id FROM", table.name,"ORDER BY id DESC LIMIT 1"))[[1]]
-        df$id <- 1:nrow(df) + n
+      last.id.list <- dbGetQuery(con, paste("SELECT id FROM", table.name,"ORDER BY id DESC LIMIT 1"))
+      if(length(last.id.list)==0)
+        n <- 0
+      else
+        n <- last.id.list[[1]]
+      df$id <- 1:nrow(df) + n
     }
   
     ## look for unloadable columns in the df
     clmn.match <- match(names(df), fields)
     if(any(is.na(clmn.match)))
-	warning(paste("Found '",names(df)[is.na(clmn.match)], "' not in fields of '", table.name,"' table. Omiting.", sep=''))
+	warning(paste("Found '",names(df)[is.na(clmn.match)], "' not in fields of '", table.name,"' table. Omiting.\n", sep=''))
   
     ## ADD! section here to check for NA values in columns mapped to NOT NULL fields
   
@@ -27,6 +31,18 @@
     if(any(is.na(reordered.names)))
       stop('Too many unmatched columns to database column list. Stopping')
     df <- df[ ,reordered.names]
+
+    
+    ## check for na's which might prevent a load
+    r <- dbSendQuery(con, paste("SELECT * FROM", table.name,"ORDER BY id DESC LIMIT 1"))
+    null.OK <- nv(dbColumnInfo(r)$nullOK, dbColumnInfo(r)$name)
+    dummy <- fetch(r)
+    reqd.fields <- names(null.OK[!null.OK])
+    na.cols <- sapply(df, function(x) any(is.na(x)) )
+    req.miss <- na.cols[reqd.fields]
+    if(any(req.miss))
+      stop(paste("Didn't load your dataframe because required field(s)", names(req.miss)[req.miss],"contained missing values"))
+
     
     ## load table
     print(paste("loading", table.name, "table to database"))
@@ -38,4 +54,4 @@
       return(df$id)
     else
       return(db.write)
-  } 
\ No newline at end of file
+  } 
